connectionmonitoring/connectionmonitorui/src/ConnectionMonitorUiAppUi.cpp
branchRCL_3
changeset 15 4dc3bb0099b0
parent 12 ea6e024ea6f9
child 54 984e13af52c4
--- a/connectionmonitoring/connectionmonitorui/src/ConnectionMonitorUiAppUi.cpp	Mon Mar 15 12:42:11 2010 +0200
+++ b/connectionmonitoring/connectionmonitorui/src/ConnectionMonitorUiAppUi.cpp	Wed Mar 31 22:15:10 2010 +0300
@@ -331,9 +331,11 @@
                         {
                         ShowConnectionSummaryInformationNoteL( connectionInfo );
                         }
                     // Mark the connection as closed. When the timer ticks the next
                     // time the marked connection is deleted and removed from the main view.
                     connectionInfo->RefreshConnectionStatus( KConnectionClosed );
+                    connectionInfo->RefreshConnectionListBoxItemTextL();
                     }                
                 CMUILOGGER_WRITE_F( "Deleted: %d", connectionId );
                 }
@@ -331,9 +331,11 @@
                         ShowConnectionSummaryInformationNoteL( connectionInfo );
                         }
-                    // Mark the connection as closed. When the timer ticks the next
-                    // time the marked connection is deleted and removed from the main view.
+                    // Mark the connection as closed and update the status text. 
+                    // When the timer ticks the next time the marked connection 
+                    // is deleted and removed from the main view.
                     connectionInfo->RefreshConnectionStatus( KConnectionClosed );